Integrated Image Processing Viewer

The goal of IIPV is to offer similar features to VPV [https://github.com/kidanger/vpv], but with Python integration and support for adding interactivity options (buttons, etc)
